# -*- coding = UTF-8 -*-
# Author   : buxiubuzhi
# Project  : lazyTest
# FileName : config.py
# Describe :
# ---------------------------------------
from selenium import webdriver
from selenium.webdriver.common.by import By
from selenium.webdriver.remote.webelement import WebElement
from selenium.webdriver.support.wait import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC

locator = {
    'i': By.ID,
    'id': By.ID,
    'n': By.NAME,
    'name': By.NAME,
    'c': By.CLASS_NAME,
    'class': By.CLASS_NAME,
    'x': By.XPATH,
    'xpath': By.XPATH,
    's': By.CSS_SELECTOR,
    'css': By.CSS_SELECTOR,
    't': By.TAG_NAME,
    'tag_name': By.TAG_NAME,
    'l': By.LINK_TEXT,
    "link_text": By.LINK_TEXT,
    'pl': By.PARTIAL_LINK_TEXT,
    'partial_link_text': By.PARTIAL_LINK_TEXT,
    'xc':By.XPATH,
    'xi':By.XPATH,
}

Dirver = {
    "Chrome": webdriver.Chrome,
    "Firefox": webdriver.Firefox,
    "Edge": webdriver.Edge,
    "ChromeOptions": webdriver.ChromeOptions,
}

# 对动态class和动态id的处理
def OPtionElements(by, value):
    if by == 'xc':
        value = '//*[contains(@class,"{}")]'.format(value)
        return value
    if by == 'xi':
        value = '//*[contains(@id,"{}")]'.format(value)
        return value
    return value


class Config:

    def __init__(self, Browser_type: str, url: str) -> None:
        """
        初始化浏览器，并输入地址
        :param Browser_type: 浏览器类型
        :param url: 需要打开的网址
        """

        self.baseDriver = Dirver[Browser_type]()
        self.baseUrl = url
        self.baseDriver.get(url)
        self.baseDriver.maximize_window()

    def implicitlyWait(self, s: int) -> None:
        """
        隐式等待
        :param s: 休眠时间，单位：秒
        :return:
        """
        self.baseDriver.implicitly_wait(s)

    def webdriver_wait(self, selector: str) -> None:
        """显示等待元素"""
        locator = self.__locate_Element_selector(selector)
        WebDriverWait(self.baseDriver, 10, 0.5).until(
            EC.presence_of_element_located(locator))

    def __locate_Element_selector(self, selector: str) -> tuple:
        """
        八种定位方式选择
        :param selector: 传入的格式必须为：定位方式，定位元素值，顺序不可改变
        :return: 返回定位方式
        """
        selector_by = selector.split(',')[0].strip()
        selector_value = selector.split(',')[1].strip()
        selector_value = OPtionElements(selector_by, selector_value)
        return locator[selector_by], selector_value

    def locate_element(self, selector: str) -> WebElement:
        """
        定位单个元素
        :param selector: 定位元素的方式和定位元素的值
        :return: 返回定位元素对象
        """
        self.webdriver_wait(selector)
        locator = self.__locate_Element_selector(selector)
        element = self.baseDriver.find_element(*locator)
        return element

    def locate_elements(self, selector: str) -> list:
        """
        定位一组元素值
        :param selector: 定位元素的方式和定位元素的值
        :return:
        """
        locator = self.__locate_Element_selector(selector)
        elements = self.baseDriver.find_elements(*locator)
        return elements



# -*- coding = UTF-8 -*-
# Author   : buxiubuzhi
# Project  : lazyTest
# FileName : template.py
# Describe :
# ---------------------------------------


# conftest.py文件模板
CONFTEST = """

# -*- coding = UTF-8 -*-
# Author   : buxiubuzhi
# Project  : lazyTest
# FileName : conftest.py
# Describe : 
# ---------------------------------------
import os
import sys
import time
import allure
import pytest

sys.path.append(os.path.dirname(os.path.dirname(__file__)))
from service.LoginService import LoginService
import lazyTest

globals()["driver"] = None


def pytest_addoption(parser):
    # pytest.ini文件自定义参数配置，想要在pytest.ini存放自定义参数，必须再此定义
    parser.addini('Terminal', help='访问浏览器参数')
    parser.addini('URL', help='添加 url 访问地址参数')
    parser.addini('setUp', help='添加 登录时前置输入的参数')
    parser.addini('username', help='添加 登录时用户名参数')
    parser.addini('password', help='添加 登录时密码参数')
    parser.addini('teardown', help='添加 登录时后置输入的参数')
    parser.addini('filepath', help='添加 截图路径')
    parser.addini('logpath', help='添加 日志路径')


@pytest.fixture(scope='session')
def getdriver(pytestconfig):
    '''
    全局的夹具配置，所有用例执行之前，和所有用例执行之后
    :param pytestconfig: 用于获取pytest.ini 中的参数
    :yield: 上面代码为前置，下面代码为后置
    '''
    Terminal = pytestconfig.getini("Terminal")
    URL = pytestconfig.getini("URL")
    driver = lazyTest.WebOption(Terminal, URL)
    globals()["driver"] = driver.baseDriver
    yield driver
    driver.baseDriver.browser_close()


@pytest.fixture(scope='session', autouse=True)
def login(getdriver, pytestconfig):
    '''
    登录业务，再此配置可在运行所有用例时只登录一次
    如果不想使用将：装饰器的autouser改为False即可
    :param getdriver: 获得驱动器
    :param pytestconfig: 从pytest.ini中获得参数
    :return: 
    '''
    lo = LoginService(getdriver)
    username = pytestconfig.getini("username")
    password = pytestconfig.getini("password")
    lo.loginService_1(username, password)


@pytest.fixture(scope="function", autouse=True)
def flush_browser(getdriver):
    '''
    每个用例执行之后刷新页面
    可通过控制装饰器的scope指定影响的级别
    可通过装饰器的autouser决定是否启用
    :param getdriver: 获取驱动器
    :return: 
    '''
    yield
    getdriver.Refresh()


@pytest.hookimpl(hookwrapper=True)
def pytest_runtest_makereport(item):
    '''
    用例失败截图
    :param item: 每个用例的信息 
    :return: 
    '''
    config = item.config
    outcome = yield
    report = outcome.get_result()
    if report.when == 'call':
        xfail = hasattr(report, 'wasxfail')
        if report.failed and not xfail:
            project = str(config.rootpath)
            filepath = config.getini("filepath")
            picture_time = time.strftime("%Y-%m-%d-%H-%M-%S", time.localtime(time.time()))
            filename = project + filepath + picture_time + ".png"
            globals()["driver"].save_screenshot(filename)
            with open(filename, "rb") as f:
                file = f.read()
                allure.attach(file, "失败截图", allure.attachment_type.PNG)


@pytest.hookimpl(hookwrapper=True, tryfirst=True)
def pytest_runtest_setup(item):
    '''配置日志输入到文件的位置'''
    config = item.config
    project = str(config.rootpath)
    logpath = config.getini("logpath")
    logging_plugin = config.pluginmanager.get_plugin("logging-plugin")
    logging_plugin.set_log_path(project + logpath)
    yield

"""
# pytest.ini文件模板
PYTEST = """
注意： 该文件不可存在中文描述，实际运行时需要将所有的注释删除
[pytest]
# 控制台输出日志配置
log_cli = true
log_cli_level = INFO
log_format = %(levelname)s %(asctime)s [%(filename)s:%(lineno)-s] %(message)s
log_date_format = %Y-%M-%D %H:%M:%S
# 文件输出日志控制
log_file_level = INFO
log_file_format = %(levelname)s %(asctime)s [%(filename)s:%(lineno)-s] %(message)s
log_file_date_format = %Y-%M-%D %H:%M:%S
#---------------------------------------------------
# 配置浏览器，支持： Chrome、Firefox、Ie、Edge、PhantomJs（无头浏览器）、ChromeOptions（谷歌提供无头）、h5（支持iPhone X）
Terminal = Chrome
# 填写需要访问页面的url，此处不需要指定路由，路由在pages层指定
URL = http://localhost:8080
# 截图存放路径，可修改，截图文件名在conftest.py文件中定义
filepath = /result/screenshot/
# 元素文件的路径
elementPath = /resources/element/   
# 元素文件类型（目前只支持yaml文件）    
suffix = .yaml                          
# 日志存放路径，可修改
logpath = /result/log/log.log
# 自定义登录参数，可根据conftest.py文件中定义的添加，如果需要其他参数，需要先在conftest.py文件中定义
username = 
password = 
#----------------------------------------------------

"""
# main.py文件模板
MAIN = """
# -*- coding = UTF-8 -*-
# Author   : buxiubuzhi
# Project  : lazyTest
# FileName : main.py
# Describe : 
# ---------------------------------------

import os
import sys

sys.path.append(os.path.dirname(os.path.dirname(__file__)))
from lazyTest import clearLogAndReport


def getPorjectPath():
    '''
    获取项目路径
    '''
    return os.path.dirname(os.path.dirname(__file__))


def runlastFailed():
    print("-------------启动失败用例重跑-------------")
    cmd = f"pytest -s --lf {getPorjectPath()}/case --alluredir {getPorjectPath()}/result/report"
    print(os.system(cmd))


def startReport():
    print("-------------启动测试报告--------------")
    cmd = f"allure serve {getPorjectPath()}/result/report"
    print(os.system(cmd))


@clearLogAndReport(getPorjectPath())
def startCase(cases = ""):
    print("------------开始执行测试------------")
    cmd = f"pytest -s {getPorjectPath()}/case/{cases} --alluredir {getPorjectPath()}/result/report"
    print(os.system(cmd))


@clearLogAndReport(getPorjectPath())
def startMarkCase(mark = ""):
    print("------------根据标签执行用例------------")
    cmd = f"pytest -s {getPorjectPath()}/case/ -m {mark} --alluredir {getPorjectPath()}/result/report"
    print(os.system(cmd))


if __name__ == '__main__':
    startCase()         # 执行所有用例
    startMarkCase()     # 执行标记用例
    runlastFailed()     # 执行失败用例
    startReport()       # 启动测试报告
"""






TEMP = {
    "conftest": CONFTEST,
    "pytest":   PYTEST,
    "main":     MAIN,
}



# -*- coding = UTF-8 -*-
# Author   : buxiubuzhi
# Project  : lazyTest
# FileName : cli.py
# Describe :
# ---------------------------------------

import argparse
import os, sys
from lazyTest import __version__, __description__
from lazyTest.template import TEMP
PY3 = sys.version_info[0] == 3


def main():
    """
    API test: parse command line options and run commands.
    """

    parser = argparse.ArgumentParser(description=__description__)
    parser.add_argument(
        '-v', '--version', dest='version', action='store_true',
        help="show version")

    parser.add_argument(
        '--project',
        help="Create an lazyTest automation test project.")

    args = parser.parse_args()

    # 获取版本
    if args.version:
        print("version {}".format(__version__))
        return 0

    # 创建项目
    project_name = args.project
    if project_name:
        create_scaffold(project_name)
        return 0





def create_scaffold(project_name):
    """
    create scaffold with specified project name.
    """
    if os.path.isdir(project_name):
        print("{}:Not a directory".format(project_name))
        return

    def create_folder(path):
        print("create dir:{}".format(path))
        os.makedirs(path)

    def create_file(path, file_content=""):
        print("create file:{}".format(path))
        with open(path, 'w', encoding='utf-8') as f:
            f.write(file_content)

    create_folder(project_name)  # 创建项目目录
    # 创建目录结构
    create_folder(os.path.join(project_name, "pages"))
    create_folder(os.path.join(project_name, "service"))
    create_folder(os.path.join(project_name, "case"))
    create_folder(os.path.join(project_name, "main"))
    create_folder(os.path.join(project_name, "result"))
    create_folder(os.path.join(project_name, "result", "log"))
    create_folder(os.path.join(project_name, "result", "report"))
    create_folder(os.path.join(project_name, "result", "screenshot"))
    create_folder(os.path.join(project_name, "resources"))
    create_folder(os.path.join(project_name, "resources", "element"))
    # 创建核心文件
    create_file(os.path.join(project_name, "__init__.py"))
    create_file(os.path.join(project_name, "case", "conftest.py"), TEMP["conftest"])
    create_file(os.path.join(project_name, "pytest.ini"), TEMP["pytest"])
    create_file(os.path.join(project_name, "main", "main.py"), TEMP["main"])




from lazyTest.file import GetElementSource,ReadIni,ReadCsvFileToList
from lazyTest.utils import Sleep, clearLogAndReport, createData,cls_Sleep
from lazyTest.case import TestCase
from lazyTest.base import  WebOption
from lazyTest.page import Page

__version__ = '2.0.5'


__author__ = 'buxiubuzhi'

__description__ = "WebUI自动化测试框架"

__all__ = [
    "Sleep",
    "Page",
    "clearLogAndReport",
    "WebOption",
    "createData",
    "TestCase",
    "cls_Sleep",
    "GetElementSource",
    "ReadIni",
    "ReadCsvFileToList"
]



# -*- coding = UTF-8 -*-
# Author   : buxiubuzhi
# Project  : lazyTest
# FileName : base.py
# Describe :
# ---------------------------------------
import functools

from lazyTest.config import Config
from selenium.webdriver.support.select import Select
from selenium.webdriver.common.action_chains import ActionChains


def _retrying(func):
    @functools.wraps(func)
    def inner(*args):
        # 如果是字符串，直接传入不进行重试
        if isinstance(args[1], str):
            result = func(*args)
            return result
        ele = iter(args[1])  # 非字符串，创建迭代器

        # 实现重试机制，报错就会重试，直到迭代所有
        def run(ele, *args):
            args = list(args)  # 兼容多个参数
            try:
                e = next(ele)
            except StopIteration:
                return
            try:
                args[1] = e  # 处理时只处理第一个参数
                result = func(*args)
                return result
            except BaseException as e:  # 捕获所有异常
                result = run(ele, *args)
            return result

        result = run(ele, *args)
        return result

    return inner


class WebOption(Config):

    def Get(self, url: str) -> None:
        urls = self.baseUrl + url
        self.baseDriver.get(urls)

    @_retrying
    def Click(self, selector: str) -> None:
        """元素点击操作"""
        ele = self.locate_element(selector)
        ele.click()

    @_retrying
    def RightClick(self, selector: str) -> None:
        """鼠标右键"""
        ele = self.locate_element(selector)
        ActionChains(self.baseDriver).context_click(selector)

    @_retrying
    def DoubleClick(self, selector: str) -> None:
        """元素双击"""
        ele = self.locate_element(selector)
        ActionChains(self.baseDriver).double_click(ele).perform()

    def DragAndDrop(self, source, target):
        """从源元素按住左键不放拖动到指定元素"""
        start = self.locate_element(source)
        end = self.locate_element(target)
        ActionChains(self.baseDriver).drag_and_drop(start, end)

    @_retrying
    def ActionScroll(self, selector: str, x: int = 0, y: int = 10):
        """内嵌滚动条滚动"""
        ele = self.locate_element(selector)
        ActionChains(self.baseDriver).drag_and_drop_by_offset(ele, x, y).perform()

    @_retrying
    def Input(self, selector: str, value: str) -> None:
        """元素输入操作"""
        ele = self.locate_element(selector)
        ele.send_keys(value)

    @_retrying
    def Clear(self, selector: str) -> None:
        """元素输入框清空输入内容"""
        ele = self.locate_element(selector)
        ele.clear()

    @_retrying
    def ClearAndInput(self, selector: str, value: str) -> None:
        """清空输入框并输入内容"""
        ele = self.locate_element(selector)
        ele.clear()
        ele.send_keys(value)

    @_retrying
    def GetText(self, selector: str) -> str:
        """获取元素文本内容"""
        ele = self.locate_element(selector)
        return ele.text

    @_retrying
    def GetTexts(self, selector: str, index: int = None) -> list:
        """获取一组元素的文本内容"""
        ele = self.locate_elements(selector)
        if index is not None:
            return ele[index].text
        else:
            text_list = [i.text for i in ele]
            return text_list

    @_retrying
    def GetElement(self,selector: str):
        """定位单个元素"""
        ele = self.locate_element(selector)
        return ele

    @_retrying
    def GetElements(self, selector: str, text: str = "",index: int = None,):
        """获取一组元素"""
        eles = []
        ele = self.locate_elements(selector)
        if text != "":
            for i in ele:
                if i.text == text:
                    eles.append(i)
            if index is not None:
                return eles[index]
            return eles
        return ele

    @_retrying
    def ElementFilterByText(self, selector: str, text: str):
        """获取一组元素，根据指定的文本进行过滤"""
        ele = self.locate_elements(selector)
        if text is not None:
            for i in ele:
                if i.text == text:
                    return i

    @_retrying
    def ElementFilterByIndex(self, selector: str, index: int = None):
        """获取一组元素，根据指定的索引进行过滤"""
        ele = self.locate_elements(selector)
        return ele[index]

    @_retrying
    def GetAttribute(self, selector: str, value: str = 'value') -> str:
        """
        获取元素属性
        textContent: 可用于获取没有在当前窗口显示的文本内容
        value： 用于获取元素的value属性
        """
        ele = self.locate_element(selector)
        return ele.get_attribute(value)

    @_retrying
    def AddAttribute(self, selector: str, attributeName: str, value: str):
        '''
        封装向页面标签添加新属性的方法
        '''
        ele = self.locate_element(selector)
        self.baseDriver.execute_script("arguments[0].%s=arguments[1]" % attributeName, ele, value)

    @_retrying
    def SetAttribute(self, selector: str, attributeName: str, value: str):
        '''
        封装设置页面对象的属性值的方法
        '''
        ele = self.locate_element(selector)
        self.baseDriver.execute_script("arguments[0].setAttribute(arguments[1],arguments[2])", ele, attributeName,
                                       value)

    @_retrying
    def SwitchFrame(self, selector: str) -> None:
        """根据框架定位元素值切换"""
        ele = self.locate_element(selector)
        self.baseDriver.switch_to.frame(ele)

    def SwitchParentFrame(self):
        """切换到父框架"""
        self.baseDriver.switch_to.parent_frame()

    def SwitchDefaultContent(self):
        """切换到默认框架"""
        self.baseDriver.switch_to.default_content()

    def SwitchWindow(self, window_Num=-1):
        """切换窗口默认切换到最后一个"""
        handles = self.baseDriver.window_handles()
        self.baseDriver.switch_to.window(handles[window_Num])

    def OperationAlert(self, operation: str = 'accept'):
        """处理弹窗"""
        alert = self.baseDriver.switch_to.alert
        if operation == 'accept':
            alert.accept()
        elif operation == 'dismiss':
            alert.dismiss()

    @_retrying
    def SelectOperation(self, selector: str, operation_type: str, value: str) -> None:
        """下拉框处理"""
        if operation_type == 'index':
            Select(self.locate_element(selector)).deselect_by_index(value)
        elif operation_type == 'value':
            Select(self.locate_element(selector)).deselect_by_value(value)
        elif operation_type == 'text':
            Select(self.locate_element(selector)).deselect_by_visible_text(value)

    def browser_close(self):
        """关闭浏览器"""
        self.baseDriver.close()

    def browser_quit(self):
        """退出浏览器"""
        self.baseDriver.quit()

    def Refresh(self):
        """刷新浏览器"""
        self.baseDriver.refresh()

    def ExcuteScript(self, script: str, *args) -> None:
        """执行js脚本"""
        self.baseDriver.execute_script(script, args)

    def JsClick(self, args):
        """通过js执行点击"""
        self.ExcuteScript("arguments[0].click();", args)

    def ExhibitionElement(self, selector: str) -> None:
        """将元素显示到可见窗口中 """
        ele = self.locate_element(selector)
        js = "arguments[0].scrollIntoView();"
        self.baseDriver.execute_script(js, ele)

    def ScrollBy(self, *args):
        """滚动操作"""
        for i in list(args):
            get_js = f"window.scrollBy(0,{i});"  # 执行多个js脚本则需要用到scrollBy；表示再次下拉到300位置
            self.baseDriver.execute_script(get_js)  # 执行js脚本

    @_retrying
    def getALlPageText(self, selector: str) -> list:
        """获取整个页面的一组元素文本，包括没有显示在当前窗口的"""
        js = "return arguments[0].textContent"
        ele = self.locate_elements(selector)
        return [self.baseDriver.execute_script(js, i) for i in ele]

    def AddCookie(self, cookie):
        """设置cookie"""
        if isinstance(cookie, dict):
            self.baseDriver.add_cookie(cookie)
        else:
            key = cookie.split("=")[0]
            value = cookie.split("=")[1]
            self.baseDriver.add_cookie({"name": key, "value": value})

    def GetCookie(self,name):
        """获取指定key的cookie"""
        return self.baseDriver.get_cookie(name)

    def GetCookies(self):
        """获取当前会话的所有cookie"""
        return self.baseDriver.get_cookies()



# -*- coding = UTF-8 -*-
# Author   : buxiubuzhi
# Project  : lazyTest
# FileName : case.py
# Describe :
# ---------------------------------------
import pytest


class TestCase:

    @pytest.fixture(scope="function")
    def setUp(self, getdriver): ...



# -*- coding = UTF-8 -*-
# Author   : buxiubuzhi
# Project  : lazyTest
# FileName : utils.py
# Describe :
# ---------------------------------------

import datetime
import inspect
import os
import time
import functools


def Sleep(s: float = 1):
    """
    每个用例的强制休眠。
    """

    def Sleep(func):
        nonlocal s

        @functools.wraps(func)
        def inner(*args):
            time.sleep(s)
            result = func(*args)
            time.sleep(s)
            return result

        return inner

    return Sleep







class cls_Sleep:
    """
    脚本运行之前和脚本运行之后执行休眠操作
    可以提高脚本执行的稳定性
    """

    def __init__(self, s: float = 0.5):
        self.s = s

    def __call__(self, func_or_cls=None):
        if inspect.isfunction(func_or_cls):
            @functools.wraps(func_or_cls)
            def wrapper(*args, **kwargs):
                time.sleep(self.s)
                result = func_or_cls(*args, **kwargs)
                time.sleep(self.s)
                return result

            return wrapper
        elif inspect.isclass(func_or_cls):
            for name, func in list(func_or_cls.__dict__.items()):
                if inspect.isfunction(func):
                    setattr(func_or_cls, name, self(func))
            return func_or_cls
        else:
            raise AttributeError


def createData(body: str = "auto{}"):
    """
    返回给定字符串拼接上时间后的字符
    """
    nowTime = datetime.datetime.strftime(datetime.datetime.now(), "%Y%m%d%H%M")[2:]
    return body.format(nowTime)


def getPorjectPath():
    """
    获取项目路径
    """
    return os.path.dirname(os.path.dirname(__file__))


def ClearTestResult(path: str):
    """
    清空目录中的文件
    参数：path：将会清除该目录下的所有文件，包括子目录文件；
    """
    for i in os.listdir(path):
        path_file = os.path.join(path, i)
        if os.path.isfile(path_file):
            os.remove(path_file)
        else:
            ClearTestResult(path_file)

def clearLogAndReport(ProjectPath):
    def clear(func):
        nonlocal ProjectPath
        @functools.wraps(func)
        def inner(*args,**kwargs):
            print("----------清空上次测试结果----------")
            path = ProjectPath + "/result"
            ClearTestResult(path)
            result = func(*args,**kwargs)
            return result
        return inner
    return clear



# -*- coding = UTF-8 -*-
# Author   : buxiubuzhi
# Project  : lazyTest
# FileName : file.py
# Describe :
# ---------------------------------------
import configparser
from typing import List
import csv
from ruamel import yaml

PAGE = "page"
ELE = "ele"


class Page:
    Document = ""
    Element = None
    Type = ""

    def __init__(self, **kwargs):
        self.Element = kwargs[ELE]


class Source:
    page = {}

    def __init__(self, **kwargs):
        self.page = kwargs[PAGE]

    def GetAllKey(self) -> List:
        keys = [i for i in self.page]
        return keys

    def GetElement(self, key: str) -> Page:
        return Page(**self.page[key])


def GetElementSource(path: str) -> Source:
    """读取yaml文件"""
    with open(path, 'r', encoding='UTF-8') as fp:
        yaml_data = yaml.safe_load(fp)
    return Source(**yaml_data)


class ReadIni:

    def __init__(self, path):
        self.config = configparser.ConfigParser()
        self.config.read(path)

    def GetIniConfig(self, section, key):
        """读取ini文件"""
        return self.config.get(section, key)



def ReadCsvFileToList(filePath):
    """读取CSV文件,参数化使用"""
    with open(filePath, 'r', encoding='utf8')as fp:
        data_list = [i for i in csv.reader(fp)]
    if len(data_list[0]) == 1:
        data_list.pop(0)  # 去首行
        return [i[0] for i in data_list]
    else:
        data_list.pop(0)  # 去首行

    return data_list



# -*- coding = UTF-8 -*-
# Author   : buxiubuzhi
# Project  : lazyTest
# FileName : page.py
# Describe :
# ---------------------------------------

import logging

import lazyTest
from lazyTest.file import *
from lazyTest.base import *


class Page(object):

    __configFile = "\\pytest.ini"

    __section = "pytest"

    def __init__(self, driver: WebOption):
        self.driver = driver
        self.lazyLog = logging.getLogger(self.getClassName())
        self.config = lazyTest.ReadIni(self.GetProjectPath() + self.__configFile)
        self.lazyLog.info(
            "元素文件: -> %s" % (
                    self.GetProjectPath() + self.__getFilePath() + self.getClassName() + self.__getSuffix()
            )
        )
        self.source = GetElementSource(
            self.GetProjectPath() + self.__getFilePath() + self.getClassName() + self.__getSuffix()
        )

    def __getFilePath(self):
        return self.config.GetIniConfig(self.__section, "elementPath")

    def __getSuffix(self):
        return self.config.GetIniConfig(self.__section, "suffix")

    def GetElement(self, key: str):
        return self.source.GetElement(key).Element

    def GetProjectPath(self) -> str: ...

    @classmethod
    def getClassName(cls):
        return cls.__name__
